#
# spec file for package docbook5-xsl-stylesheets
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define dbstyle_dir            %{_datadir}/xml/docbook/stylesheet/nwalsh5
%define dbstyle_catalog        %{name}.xml
%define suse_catalog           %{_sysconfdir}/xml/suse-catalog.xml
%define xmlcatalog             %{_bindir}/xmlcatalog
%define dbstyle_catalog_entry  for-catalog-%{name}-%{version}.xml

Name:           docbook5-xsl-stylesheets
Summary:        XSL Stylesheets for DocBook 5
License:        SUSE-Docbook-XSL and Apache-2.0 and MIT and EPL-1.0 and MPL-1.1 and BSD-3-Clause and HPND and Zlib and LGPL-2.1+
Group:          Productivity/Publishing/DocBook
BuildRequires:  fdupes
BuildRequires:  sgml-skel
BuildRequires:  unzip
BuildArch:      noarch
Requires:       docbook_5
Requires:       xmlcharent
PreReq:         sgml-skel %{_bindir}/xmlcatalog
Version:        1.78.1
Release:        11.23
Source0:        http://switch.dl.sourceforge.net/sourceforge/docbook/docbook-xsl-ns-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
# Patch0:        %%{name}-dbtoepub.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://sourceforge.net/projects/docbook/

%description
These are the XSL stylesheets for DocBook. Generally, the stylesheets
are namespace aware and you should use these for DocBook 5 only. The
stylesheets transforms your DocBook 5 document into (X)HTML, Manpages,
XSL-FO (for PDF) and a some other formats. XSL is a standard W3C
stylesheet language for both print and online rendering. For more
information about XSL, see the XSL page at theW3C.


#--------------------------------------------------------------------------
%prep
%setup -q -n docbook-xsl-ns-%{version}
# %%patch0 -p1

# These scripts are available in the docbook-xsl-stylesheet-scripts subpackage
rm fo/pdf2index slides/images/callouts/gen.sh epub/bin/dbtoepub 

#--------------------------------------------------------------------------
%build

#
# Creating catalog entries
#

#
# /etc/xml/docbook-xsl-stylesheets.xml
#
%{xmlcatalog} --noout --create %{dbstyle_catalog}
%{xmlcatalog} --noout --add "rewriteSystem" \
 "http://docbook.sourceforge.net/release/xsl-ns/%{version}" \
 "file://%{dbstyle_dir}/%{version}" %{dbstyle_catalog}
%{xmlcatalog} --noout --add "rewriteURI" \
 "http://docbook.sourceforge.net/release/xsl-ns/%{version}" \
 "file://%{dbstyle_dir}/%{version}" %{dbstyle_catalog}
%{xmlcatalog} --noout --add "rewriteSystem" \
 "http://docbook.sourceforge.net/release/xsl-ns/current" \
 "file://%{dbstyle_dir}/%{version}" %{dbstyle_catalog}
%{xmlcatalog} --noout --add "rewriteURI" \
 "http://docbook.sourceforge.net/release/xsl-ns/current" \
 "file://%{dbstyle_dir}/%{version}" %{dbstyle_catalog}

#
# temporary file that is added to /etc/xml/suse-catalog.xml
# during post
#
%{xmlcatalog} --noout --create %{dbstyle_catalog_entry}
%{xmlcatalog} --noout --add "delegateSystem" \
  "http://docbook.sourceforge.net/release/xsl-ns/" \
  "file:///etc/xml/%{dbstyle_catalog}" %{dbstyle_catalog_entry}
%__sed -i -e '/<catalog/a\ <group id="%{name}">' \
       -e '/<\/catalog/i\ </group>' %{dbstyle_catalog_entry}

#--------------------------------------------------------------------------
%install

# Create directories
%__mkdir_p -m755 %{buildroot}%{_bindir}
%__mkdir_p -m755 %{buildroot}%{dbstyle_dir}/%{version}
%__mkdir_p -m755 %{buildroot}%{_defaultdocdir}/%{name}/html
%__mkdir_p -m755 %{buildroot}%{_sysconfdir}/xml

# Install scripts
# Don't install *any* scripts as these are located now in the 
# docbook-xsl-stylesheets-scripts subpackage

# VERSION.xsl
%__install -m644 VERSION.xsl %{buildroot}%{dbstyle_dir}/%{version}

# all the rest is located in subdirectories, exclude some subdirectories with
# stuff not needed
for DIR in $(find -maxdepth 1 -mindepth 1 -type d \( -name "tools" -o -name "doc" -o -name "docsrc" -o -name "tests" \) -prune -o -type d -print ); do
    %__tar c $DIR | (cd %{buildroot}%{dbstyle_dir}/%{version}; %__tar xp);
done
# fixing permission errors from sources
find %{buildroot}%{dbstyle_dir}/%{version} -type f -exec %__chmod 644 {} \;
find %{buildroot}%{dbstyle_dir}/%{version} -type d -exec %__chmod 755 {} \;
%__chmod 755 %{buildroot}%{dbstyle_dir}/%{version}/extensions/xslt.py

# create current link
# but not for snapshots
#
if ! echo %{S:0} | grep -q snapshot; then
    pushd %{buildroot}%{dbstyle_dir} >/dev/null
    ln -sf %{version} current
    popd >/dev/null
fi

# install the catalog files
#
%__install -m644 %{dbstyle_catalog} %{buildroot}%{_sysconfdir}/xml
%__install -m644 %{dbstyle_catalog_entry} %{buildroot}%{_sysconfdir}/xml

# the docs come last
#
# %%__tar c -C doc . | (cd %%{buildroot}%%{_defaultdocdir}/%%{name}/html; %%__tar xp);

%fdupes -s %{buildroot}

#--------------------------------------------------------------------------
%post
#
# XML Catalog entries for daps profiling
#
# remove existing entries first (if existing) - needed for
# zypper in, since it does not call postun
#
# in case of an update, remove old
if [ "2" = "$1" ]; then
  %{_bindir}/edit-xml-catalog --group --catalog %{suse_catalog} --del %{name}
fi
%{_bindir}/edit-xml-catalog --group --catalog %{suse_catalog} \
  --add %{_sysconfdir}/xml/%{dbstyle_catalog_entry}

exit 0

#--------------------------------------------------------------------------
%postun
#
# delete catalog entry for daps profiling
# only run if package is really uninstalled ($1 = 0) and not
# in case of an update
#
if [ 0 = $1 ]; then 
  %{_bindir}/edit-xml-catalog --group --catalog %{suse_catalog} --del %{name}
fi

exit 0

#--------------------------------------------------------------------------
%files
%defattr(-, root, root)

%dir %{_datadir}/xml/docbook/stylesheet
%dir %{dbstyle_dir}
%dir %{dbstyle_dir}/%{version}

%exclude %{dbstyle_dir}/%{version}/slides/slidy/.htaccess
%exclude %{dbstyle_dir}/%{version}/slides/slidy/*/.htaccess

%config %{_sysconfdir}/xml/*.xml

%doc BUGS NEWS README RELEASE-NOTES.txt TODO

# NO bindir
# %%{_bindir}/*
%{dbstyle_dir}/current
%{dbstyle_dir}/%{version}/*

%changelog
* Fri Jul  5 2013 toms@opensuse.org
- Update to 1.78.1, see http://snapshots.docbook.org/xsl/RELEASE-NOTES.html#V1.78.1
  for details
- Updated spec file to avoid packaging .htaccess files; removed
  some scripts which are packaged in docbook-xsl-stylesheets-scripts
* Fri Jun 28 2013 toms@opensuse.org
- Corrected conflict with docbook-xsl-stylesheets:
  Created subpackage with pdf2index (which raised this conflict)
  and moved other scripts too (db2epub, callout-gen).
  This makes it easier to install both variantes of the
  stylesheets
* Fri May 31 2013 varkoly@suse.com
- Fix spec to avoid conflicts with docbook-xsl-stylesheets
* Fri Mar 15 2013 fsundermeyer@opensuse.org
- fixed error in specfile that generated catalog entries pointing
  to the DocBook4 stylesheets
* Tue Sep 18 2012 cfarrell@suse.com
- license update: SUSE-Docbook-XSL and Apache-2.0 and MIT and EPL-1.0 and
  MPL-1.1 and BSD-3-Clause and HPND and Zlib and LGPL-2.1+
  Package aggregates all of the above licenses. Added SUSE-Docbook-XSL
  instead of MIT as the COPYING file is not ^pure^ MIT but contains two
  additional clauses
* Fri Sep 14 2012 toms@opensuse.org
- Fixed bnc#780451: used docbook_5 instead of docbook_4; fixed typo
  in summary
* Thu Jun 14 2012 toms@opensuse.org
- Updated to 1.77.1, see http://snapshots.docbook.org/xsl/RELEASE-NOTES.html#V1.77.1
  for details (Mostly bugfix release)
- Made spec file consistent with docbook-xsl-stylesheet package
  (it's mostly the same)
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Sun Nov 21 2010 toganm@opensuse.org
- Updated to 1.76.1 The following is a list of changes that have been made
  since the 1.76.0 release.
  FO
  The following changes have been made to the fo code since the 1.76.0
  release.
  ● Robert Stayton: docbook.xsl; xref.xsl; fop1.xsl
    Apply patch to support named destination in fop1.xsl, per Sourceforge
    bug report #3029845.
  HTML
  The following changes have been made to the html code since the 1.76.0
  release.
  ● Keith Fahlgren: highlight.xsl
    Implementing handling for <b> and <i>: transform to <strong> and <em>
    for XHTML outputs and do not use in the highliting output (per Mauritz
    Jeanson)
  Params
  The following changes have been made to the params code since the 1.76.0
  release.
  ● Robert Stayton: draft.mode.xml
    Change default for draft.mode to 'no'.
* Mon Aug 17 2009 aj@suse.de
- Only remove file from catalog if it disappeared.
- Do not use release numbers, they're not needed anymore.
* Wed Jun  3 2009 toms@suse.de
  SPEC file: added fdupes
  Updated to version 1.75.1:
  The following changes have been made to the fo code since the 1.75.0 release.
  FO
  - Keith Fahlgren: block.xsl
    Switching to em dash for character before attribution in epigraph;
    resolves Bug #2793878
  - Robert Stayton: lists.xsl
  - Fixed bug 2789947, id attribute missing on simplelist fo output.
  HTML
  - Keith Fahlgren: block.xsl
  - Switching to em dash for character before attribution in epigraph;
    resolves Bug #2793878
  - Robert Stayton: lists.xsl
  - Fixed bug 2789678: apply-templates line accidentally deleted.
  Epub
  - Keith Fahlgren: bin/spec/epub_regressions_spec.rb; docbook.xsl
    Added regression and fix to correct "bug" with namespace-prefixed container
    elements in META-INF/container.xml ; resolves Issue #2790017
  - Keith Fahlgren: bin/spec/epub_regressions_spec.rb; bin/spec/files/
    onegraphic.xinclude.xml;⋯
    Another attempt at flexible named entity and XInclude processing
  - Keith Fahlgren: bin/lib/docbook.rb
    Tweaking solution to Bug #2750442 following regression reported by Michael Wiedmann.
  Params
  - Mauritz Jeanson: highlight.source.xml
    Updated documentation to reflect changes made in r8419.
* Fri Feb 20 2009 toms@suse.de
  * Added rpmlintrc file
  * Changed spec file a bit to be more conformant to OBS
  Updated to version 1.74.2
  * Lots of changes in localization, epub,
  * Bugs fixed: #2000787, #2082455, #2269202, #2020982, #2574111,
  [#2298384], #2020774, #1838213, #2086321, #2067318, #2060418,
  [#2034582], #2329704, #2034582, #2013441, #1913376, #1859831,
  [#1876282], #2013441,
  * See file RELEASE-NOTES.{txt,html,pdf,xml} for more details
* Thu Jul 24 2008 toms@suse.de
  Updated to version 1.74.0:
  * Paul Norton (Adobe) and Keith Fahlgren (O'Reilly Media) have donated
  code that generates .epub documents from DocBook input. An
  alpha-reference implementation in Ruby has also been provided.
  .epub is an open standard of the The International Digital Publishing
    Forum (IDPF), a the trade and standards association for the digital
    publishing industry. Read more about this target in epub/README
  * XHTML 1.1 target
  To support .epub output, a strict XHTML 1.1 target has been added.
  The stylesheets for this output are generated and are quite similar to
  the XHTML target.
  * Gentext updates
  A number of locales have been updated.
  * Roundtrip improvements
  Table, figure, template syncronization, and character style improvements
  have been made for WordML & Pages. Support added for OpenOffice.org.
  * First implementation of a libxslt extension
  A stylesheet extension for libxslt, written in Python, has been added.
  The extension is a function for adjusting column widths in CALS tables.
  See extensions/README.LIBXSLT for more information.
  Fixed bugs since the 1.73.2 release:
  [#1838136], #1811721, #1759205, #1797492, #1891965, #1854199,
  [#1669658], #1740964, #1680836, #1888169, #1854199, #1790495,
  [#1680836], #1790495, #1894244, #1858329, #1648360, #1648360,
  [#1648360], #1785224
  See http://docbook.xml-doc.org/snapshots/xsl-ns/RELEASE-NOTES.html#V1.74.0
  for more information.
* Mon Feb  4 2008 toms@suse.de
- Corrected URIs for accessing the DocBook XSL NS stylesheets. Uses
  the "official" URI now:
    http://docbook.sourceforge.net/release/xsl-ns/current/FORMAT/
  (see the "xsl-ns" instead of "xsl". The latter is used by the
  docbook-xsl-stylesheet package.)
* Sat Dec 22 2007 coolo@suse.de
- remove conflict with docbook-xsl-stylesheet as they obsoleted both
  the same
* Mon Aug 20 2007 toms@suse.de
- Update to version 1.73.1, bugfix release:
  Gentext:
  * Mauritz Jeanson: locale/de.xml
    Applied patch #1766009.
  * Michael(tm) Smith: locale/lv.xml
    Added localization for ProductionSet.
  FO:
  * Mauritz Jeanson: table.xsl
    Modified the tgroup template so that, for tables with multiple tgroups,
    a width attribute is output on all corresponding fo:tables. Previously,
    there was a test prohibiting this (and a comment saying that outputting more
    than one width attribute will cause an error). But this seems to be no longer
    relevant; it is not a problem with FOP 0.93 or XEP 4.10. Closes bug #1760559.
  * Mauritz Jeanson: graphics.xsl
    Replaced useless <a> elements with warning messages (textinsert extension).
  * Mauritz Jeanson: admon.xsl
    Enabled generation of ids (on fo:wrapper) for indexterms in admonition titles,
    so that page references in the index can be created. Closes bug #1775086.
  HTML:
  * Mauritz Jeanson: titlepage.xsl
    Added <xsl:call-template name="process.footnotes"/> to abstract template
    so that footnotes in info/abstract are processed. Closes bug #1760907.
  * Michael(tm) Smith: pi.xsl; synop.xsl
    Changed handling of HTML output for the cmdsynopsis and
    funcsynopsis elements, such that a@id instances are generated for
    them if they are descendants of any element containing a dbcmdlist
    or dbfunclist PI. Also, update the embedded reference docs for the
    dbcmdlist and dbfunclist PIs to make it clear that they can be
    used within any element for which cmdsynopsis or funcsynopsis are
    valid children.
  * Michael(tm) Smith: formal.xsl
    Reverted the part of revision 6952 that caused a@id anchors to be
    generated for output of informal objects. Thanks to Sam Steingold
    for reporting.
  * Robert Stayton: glossary.xsl
    Account for a glossary with no glossdiv or glossentry children.
  * Mauritz Jeanson: titlepage.xsl
    Modified legalnotice template so that the base.name parameter is calculated
    in the same way as for revhistory chunks. Using <xsl:apply-templates
    mode="chunk-filename" select="."/> did not work for single-page output since
    the template with that mode is in chunk-code.xsl.
  * Mauritz Jeanson: graphics.xsl
    Updated support for SVG (must be a child of imagedata in DB 5).
    Added support for MathML in imagedata.
  * Mauritz Jeanson: pi.xsl
    Added documentation for the dbhh PI (used for context-sensitive HTML Help).
    (The two templates matching 'dbhh' are still in htmlhelp-common.xsl).
  Manpages:
  * Michael(tm) Smith: endnotes.xsl
    In manpages output, generate warnings about notesources with
    non-para children only if the notesource is a footnote or
    annotation. Thanks to Sam Steingold for reporting problems with
    the existing handling.
  HTMLHelp:
  * Michael(tm) Smith: htmlhelp-common.xsl
    Added single-pass namespace-stripping support to the htmlhelp,
    eclipse, and javahelp stylesheets.
  Eclipse:
  * Michael(tm) Smith: eclipse.xsl
    Added single-pass namespace-stripping support to the htmlhelp,
    eclipse, and javahelp stylesheets.
  JavaHelp:
  * Michael(tm) Smith: javahelp.xsl
    Added single-pass namespace-stripping support to the htmlhelp,
    eclipse, and javahelp stylesheets.
  Roundtrip:
  * Steve Ball: blocks2dbk.xsl; blocks2dbk.dtd; pages2normalise.xsl
    Modularised blocks2dbk to allow customisation,
    Added support for tables to pages2normalise
  Params:
  * Robert Stayton: procedure.properties.xml
    procedure was inheriting keep-together from formal.object.properties, but
    a procedure does not need to be kept together by default.
  * Dave Pawson: title.font.family.xml;
    component.label.includes.part.label.xml; table.frame.b
    Regular formatting re-org.
* Wed Jul 25 2007 toms@suse.de
- New release 1.73.0
  * Added Latvian and Esperanto translation, fixes in other locales
  * Description of all available PIs
  * Fix bug 1668629 valign on tbody not inherited.
  * Added template for xref to area/areaset.
    Part of fix for bug #1675513 (xref to area broken).
  * Fixed bug #1711508 (lists.xsl)
  * Added support for spacing="compact" in variablelist,
    per bug report #1722540.
  * Fixed bug #1669601 (footnote.xsl)
  * Fixed #1680755 (keycombo joinchar default incorrect).
  * Fixed bug 1652360 empty link with xlink:href.
  * Add support for default.table.frame parameter.
    Fix bug 1575446 rowsep last check for @morerows.
  => More in NEWS
* Mon May  7 2007 toms@suse.de
- Corrected BuildRequires
* Thu Mar 15 2007 toms@suse.de
- Fixed installed paths: .../stylesheet5 -> .../stylesheet,
  .../nwalsh -> .../nwalsh5
* Tue Feb 27 2007 toms@suse.de
- First release 1.72.0 of DocBook XSL Stylesheets for DocBook 5
